#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.11
visibility:           public
id:                   typst-0.11-HhpxTSsxOjPHFGYf5Zr4i6
key:                  typst-0.11-HhpxTSsxOjPHFGYf5Zr4i6
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.15
    and currently offers only partial support.

category:             Text
abi:                  01d2edc578641c50830c9f68b39fe50e
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Paths_typst Typst.Bind Typst.Regex Typst.Show Typst.Constructors
    Typst.Module.Standard Typst.Module.Math Typst.Module.Calc
    Typst.MathClass

import-dirs:          /usr/lib/ghc-9.6.6/site-local/typst-0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/typst-0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/typst-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.11-HhpxTSsxOjPHFGYf5Zr4i6
depends:
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u array-0.5.6.0 base-4.18.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-AEpRMw01iAkG9d9ZRt6Fzh
    containers-0.6.7 directory-1.3.8.5
    erf-2.0.0.0-4xz1P35HuR5Dy4ovZUgjCU filepath-1.4.300.1 mtl-2.3.1
    ordered-containers-0.2.4-B2ygMaAej7HKwtNIbE3uMJ parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.6-G1rwxCg3bOv6wSXzJT4zAX
    scientific-0.3.8.1-A5wXYZ7oCLNAWLoDifRRUz text-2.0.2 time-1.12.2
    toml-parser-2.0.2.0-8M0STb4OgU61iHBwcGwGPg
    typst-symbols-0.3-4dNsmXLN7eG8YIKTGZO3LG
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk
    xml-conduit-1.9.1.4-BJAPIc3ZpEX9Hl5GLrN5ZY
    yaml-0.11.11.2-CwFCe6z7zbF6EHPQfr57mP

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

